@@ -36,7 +36,7 @@ impl CargoToml {
             "Can't read Cargo.toml at {}",
             manifest_file.as_ref().display(),
         ))?;
-        let cargo_toml = toml_edit::easy::from_str(&contents).context(format!(
+        let cargo_toml = toml::from_str(&contents).context(format!(
             "Failed to parse Cargo.toml at {}",
             manifest_file.as_ref().display()
         ))?;
@@ -64,6 +64,7 @@ impl CargoToml {
                 "scripts",
                 "classifiers",
                 "classifier",
+                "data",
                 "maintainer",
                 "maintainer-email",
                 "requires-dist",
@@ -101,17 +102,12 @@ struct CargoTomlMetadata {
 #[derive(Serialize, Deserialize, Debug, Clone, Default)]
 #[serde(rename_all = "kebab-case")]
 pub struct RemainingCoreMetadata {
-    pub name: Option<String>,
-    /// The directory with python module, contains `<module_name>/__init__.py`
-    pub python_source: Option<String>,
-    /// The directory containing the wheel data
-    pub data: Option<String>,
     #[serde(flatten)]
-    pub other: HashMap<String, toml_edit::easy::Value>,
+    pub other: HashMap<String, toml::Value>,
 }
 
 #[cfg(test)]
-mod test {
+mod tests {
     use super::*;
     use indoc::indoc;
 
@@ -137,10 +133,15 @@ mod test {
             [package.metadata.maturin]
             classifiers = ["Programming Language :: Python"]
             requires-dist = ["flask~=1.1.0", "toml==0.10.0"]
+
+            [[package.metadata.maturin.targets]]
+            name = "pyo3_pure"
+            kind = "lib"
+            bindings = "pyo3"
         "#
         );
 
-        let cargo_toml: Result<CargoToml, _> = toml_edit::easy::from_str(cargo_toml);
+        let cargo_toml: Result<CargoToml, _> = toml::from_str(cargo_toml);
         assert!(cargo_toml.is_ok());
     }
 
@@ -168,7 +169,7 @@ mod test {
         "#
         );
 
-        let cargo_toml: Result<CargoToml, _> = toml_edit::easy::from_str(cargo_toml);
+        let cargo_toml: Result<CargoToml, _> = toml::from_str(cargo_toml);
         assert!(cargo_toml.is_ok());
     }
 }
